@@ -22,6 +22,10 @@
 #' prod(x) * sum(x)
 Schur <- function(x, lambda, algorithm = "DK"){
   algorithm <- match.arg(algorithm, c("DK", "naive"))
+  stopifnot(
+    is.vector(x) || is.bigq(x),
+    is.numeric(x) || is.complex(x) || is.bigq(x)
+  )
   if(algorithm == "DK"){
     SchurEval(x, lambda)
   }else{
